<?php
/**
 * Created by PhpStorm.
 * User: phillipesilva
 * Date: 01/07/14
 * Time: 13:18
 */

namespace Geral\Logic\FormularioEletronico;

use Geral\Entities\Setor;
use Geral\Entities\Operador;
use TeknisaLib\Config\Config;
use Setforms2\Shared\Notifier;
use Setforms2\Runtime\Framework;
use Setforms2\Shared\Business\Notification;
use Setforms2\Runtime\Helper\Report\TkBirtReport;

class Formulario
{
    public static function montaUrl($parametros, $reportName)
    {
        foreach($parametros as &$parametro) {
            $parametro = self::replaceAcentos($parametro, true);
        }

        foreach($parametros as &$parametro) {
            $parametro = self::replaceSpecialChars($parametro, true);
        }

        $birt = TkBirtReport::getInstance();
        $birt->setReport($reportName, TkBirtReport::REL_ESTATICO);
        $birt->setParameterValuesFromArray($parametros, TkBirtReport::FORMAT_PDF);
        $url = $birt->getUrl();

        return $url;
    }

    /*
     *@param $configReportNameDir -> String com o tipo de formulário que foi criado no project.ini, que será usada como função.
     *                               Ex.: 'Formularioadmissao', 'Formularioremanejamento'...
     *                               Obs.: Lembrar de passar com as letras maiúsculas onde necessário!
     *
     *@param $message             -> Corpo da mensagem do email.
     */
    public static function enviarEmail($emailOpe, $emailCC, $assunto, $anexo, $email, $configReportNameDir, $message)
    {
        $envio        = Notifier::factory();
        $notification = new Notification();

        $emailCC   = str_replace(array(';',' '), array(',', ''),$emailCC);
        $emCCDados = explode(',', $emailCC);

        $email  = str_replace(array(';'), array(','),$email);
        $email  = str_replace(array(' '), array(''),$email);
        $email  = explode(',', $email);

        $images = '<img src="https://www.security.teknisa.com/_imagens/logtek.jpg" src="https://www.security.teknisa.com/_imagens/logtek.jpg"/>';

        $strConfig  = 'get'.$configReportNameDir.'FormularioDir';
        $anexo      = Config::getInstance()->{$strConfig}().DIRECTORY_SEPARATOR.$anexo;

        $anexo      = realpath($anexo);
        $mesageBody = $images.$message;

        try
        {
            //Com anexos e com CC
            if($anexo != '' && !(is_null($emailCC) || $emailCC == ''))
            {
                $notification->setSubject($assunto);
                $notification->setFrom($emailOpe);
                $notification->setTo($email);
                $notification->setCc($emCCDados);
                $notification->setBody($mesageBody);
                $notification->setAttachments(array($anexo));
                $notification->setName('Teknisa Software LTDA');
                $envio->setNotificationBusiness($notification);
            }
            //Com anexos e sem CC
            elseif($anexo != '' && (is_null($emailCC) || $emailCC == '') )
            {
                $notification->setSubject($assunto);
                $notification->setFrom($emailOpe);
                $notification->setTo($email);
                $notification->setBody($mesageBody);
                $notification->setAttachments(array($anexo));
                $notification->setName('Teknisa Software LTDA');
                $envio->setNotificationBusiness($notification);
            }

            $envio->send();

        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function getOpcoesAutoComplete($funcao)
    {
        $opcoes = Config::getInstance()->{$funcao}();
        $opcoes = explode(';', $opcoes);

        foreach($opcoes as &$opcao){
            $opcao = array('VALUE' => ltrim($opcao), 'DESCRIPTION' => ltrim($opcao));
        }

        return $opcoes;
    }

    public static function geraRelatorio($url, $file)
    {
        $fp = fopen ($file, 'w+');
        $ch = curl_init($url);

        curl_setopt_array($ch, array(
            CURLOPT_URL            => $url,
            CURLOPT_BINARYTRANSFER => 1,
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_FILE           => $fp,
            CURLOPT_TIMEOUT        => 200,
            CURLOPT_USERAGENT      => 'Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)',
            CURLOPT_PROXY          => '192.168.122.3',
            CURLOPT_PROXYUSERPWD   => 'report:reporttek',
            CURLOPT_PROXYPORT      => 8080,
            CURLOPT_PROXYTYPE      => 'HTTP'
        ));

        if(curl_exec($ch) === false){
            echo 'Curl error: ' . curl_error($ch);
        }
        curl_close($ch);
        fclose($fp);
    }

    public static function replaceAcentos($campo, $convertToURL = null)
    {
        //Array com possíveis caracteres com acento
        $caracteresAcento   = array('Ÿ', 'À', 'Á', 'Â', 'Ã', 'Ä', 'Ç', 'È', 'É', 'Ê', 'Ë', 'Ì', 'Í',
                                    'Î', 'Ï', 'Ñ', 'Ò', 'Ó', 'Ô', 'Õ', 'Ö', 'Ù', 'Ú', 'Û', 'Ü', 'Ý',
                                    'à', 'á', 'â', 'ã', 'ä', 'ç', 'è', 'é', 'ê', 'ë', 'ì', 'í', 'î',
                                    'ï', 'ñ', 'ò', 'ó', 'ô', 'õ', 'ö', 'ù', 'ú', 'û', 'ü', 'ý', 'ÿ');

        //Array com caracteres sem acento
        $caracteresSemAcento = array('Y', 'A', 'A', 'A', 'A', 'A', 'C', 'E', 'E', 'E', 'E', 'I', 'I',
                                     'I', 'I', 'N', 'O', 'O', 'O', 'O', 'O', 'U', 'U', 'U', 'U', 'Y',
                                     'a', 'a', 'a', 'a', 'a', 'c', 'e', 'e', 'e', 'e', 'i', 'i', 'i',
                                     'i', 'n', 'o', 'o', 'o', 'o', 'o', 'u', 'u', 'u', 'u', 'y', 'y');

        //Converte os caracteres com acento para caracteres sem acento
        if ($convertToURL) {
            $campo = str_replace($caracteresAcento, $caracteresSemAcento, $campo);
        } else { //Converte caracteres sem acento para caracteres com acento
            $campo = str_replace($caracteresSemAcento, $caracteresAcento, $campo);
        }

        return $campo;

    }

    public static function replaceSpecialChars($campo, $convertToURL = null)
    {
        //Array com possíveis caracteres especiais
        $specialChar = array( '%', ' ', 'ƒ', '„', '…', '†', '‡', 'ˆ', '‰', 'Š', '‹', 'Œ', 'Ž', '‘', '’',
                             '“', '”', '•', '–', '—', '˜', '™', 'š', '›', 'œ', 'ž', 'Ÿ', '¡', '¢',
                             '£', '¤', '¥', '¦', '§', '¨', '©', 'ª', '«', '¬', '®', '¯', '°', '±',
                             '²', '³', '´', 'μ', '¶', '·', '¸', '¹', 'º', '»', '¼', '½', '¾', '¿',
                             'À', 'Á', 'Â', 'Ã', 'Ä', 'Å', 'Æ', 'Ç', 'È', 'É', 'Ê', 'Ë', 'Ì', 'Í',
                             'Î', 'Ï', 'Ð', 'Ñ', 'Ò', 'Ó', 'Ô', 'Õ', 'Ö', '×', 'Ø', 'Ù', 'Ú', 'Û',
                             'Ü', 'Ý', 'Þ', 'ß', 'à', 'á', 'â', 'ã', 'ä', 'å', 'æ', 'ç', 'è', 'é',
                             'ê', 'ë', 'ì', 'í', 'î', 'ï', 'ð', 'ñ', 'ò', 'ó', 'ô', 'õ', 'ö', '÷',
                             'ø', 'ù', 'ú', 'û', 'ü', 'ý', 'þ', 'ÿ', chr(10));

        //Array com seus códigos em URL-encoding.
        $specialCharURL = array( '%25', '%20', '%83', '%84', '%85', '%86', '%87', '%88', '%89', '%8A', '%8B',
                                '%8C', '%8E', '%91', '%92', '%93', '%94', '%95', '%96', '%97', '%98',
                                '%99', '%9A', '%9B', '%9C', '%9E', '%9F', '%A1', '%A2', '%A3', '%A4',
                                '%A5', '%A6', '%A7', '%A8', '%A9', '%AA', '%AB', '%AC', '%AE', '%AF',
                                '%B0', '%B1', '%B2', '%B3', '%B4', '%B5', '%B6', '%B7', '%B8', '%B9',
                                '%BA', '%BB', '%BC', '%BD', '%BE', '%BF', '%C0', '%C1', '%C2', '%C3',
                                '%C4', '%C5', '%C6', '%C7', '%C8', '%C9', '%CA', '%CB', '%CC', '%CD',
                                '%CE', '%CF', '%D0', '%D1', '%D2', '%D3', '%D4', '%D5', '%D6', '%D7',
                                '%D8', '%D9', '%DA', '%DB', '%DC', '%DD', '%DE', '%DF', '%E0', '%E1',
                                '%E2', '%E3', '%E4', '%E5', '%E6', '%E7', '%E8', '%E9', '%EA', '%EB',
                                '%EC', '%ED', '%EE', '%EF', '%F0', '%F1', '%F2', '%F3', '%F4', '%F5',
                                '%F6', '%F7', '%F8', '%F9', '%FA', '%FB', '%FC', '%FD', '%FE', '%FF',
                                '%0A');

        //Converter para URL-encoding.
        if ($convertToURL) {
            $campo = str_replace($specialChar, $specialCharURL, $campo);
        } else { //Converter para Texto.
            $campo = str_replace($specialCharURL, $specialChar, $campo);
        }

        return $campo;
    }

    public static function getNmSetorOperador($cdOperador)
    {
        $operador = Operador::findOneByCdoperador($cdOperador);
        $setor    = Setor::findOneByCdsetor($operador->getCdsetor());

        return $setor->getNmSetor();
    }

    public static function getDataSetLinhaValorLigacoes()
    {
        $newDataSet = array();
        $dataset    = Framework::getInstance()->getDataset();

        //Se não existirem 20 posições no DataSet é necessário criar as posições que naum foram modificadas.
        if(count($dataset) < 20) {
            for($i = 0; $i < 20; $i++) {
                $auxDataSet = false;
                foreach($dataset as $data) {
                    if($data['ORDEM'] - 1 == $i) {
                        $auxDataSet = true;
                        break;
                    }
                }

                //Se a posição existir no array DataSet pega a mesma.
                if($auxDataSet) {
                    $newDataSet[$i] = $data;
                } else {//Se não, criar outra posição com valores nulos.
                    $newDataSet[$i] = array('LINHA1' => '',
                        'VALOR1' => '',
                        'LINHA2' => '',
                        'VALOR2' => '',
                        'LINHA3' => '',
                        'VALOR3' => '',
                        'LINHA4' => '',
                        'VALOR4' => '',
                        'LINHA5' => '',
                        'VALOR5' => '',
                        'ORDEM'  => $i);
                }
            }
            return $newDataSet;
        }

        return $dataset;
    }
} 